# frozen_string_literal: true

require 'jekyll/utils'
require_relative '../core_extensions'

module SuttyMigration
  module Jekyll
    module DocumentCreator
      class DocumentExists < ArgumentError; end
      def self.included(base)
        base.class_eval do

      # Creates a new document in a collection or fails if it already
      # exists.
      #
      # @param :site [Jekyll::Site] Jekyll site
      # @param :date [Time] Post date
      # @param :title [String] Post title
      # @param :slug [String] Post slug, slugified title if empty
      # @param :collection [Jekyll::Collection,String] Collection label or collection
      # @return [Jekyll::Document] A new document
      def self.create(site:, date:, title:, slug: nil, collection:)
        collection = site.collections[collection] if collection.is_a? String
        slug = ::Jekyll::Utils.slugify(title, mode: 'latin') if slug.blank?
        basename = "#{date.strftime('%F')}-#{slug}.markdown"
        path = File.join(collection.directory, basename)

        raise DocumentExists, "#{path} already exists" if File.exist? path

        ::Jekyll::Document.new(path, site: site, collection: collection).tap do |document|
          collection.docs << document
          document.data['title'] = title
        end
      end
        end
      end
    end
  end
end

::Jekyll::Document.include SuttyMigration::Jekyll::DocumentCreator
